=======
Credits
=======

Development Lead
----------------

* Marco Berzborn - Institute of Technical Acoustics <marco.berzborn@akustik.rwth-aachen.de>

Contributors
------------

* Johannes Imort <johannes.imort@rwth-aachen.de>
